# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import shutil

import fixtures

from subprocess import check_call

CONTACTS_DB_DIR = '~/.local/share/evolution/addressbook/system/'


class BackupContacts(fixtures.Fixture):

    """Backup contacts when the fixture is used. Restore them in cleanup."""

    def __init__(self):
        """Initialize the fixture."""
        super().__init__()

    def setUp(self):
        super().setUp()
        self.tempdir_fixture = self.useFixture(fixtures.TempDir())
        contacts_database_path = (
            os.path.join(os.path.expanduser(CONTACTS_DB_DIR), 'contacts.db'))
        shutil.copy(contacts_database_path, self.tempdir_fixture.path)
        self.addCleanup(self._restore_database)

        self._restart_service()

    def _restore_database(self):
        shutil.copy(
            os.path.join(self.tempdir_fixture.path, 'contacts.db'),
            os.path.expanduser(CONTACTS_DB_DIR))

        self._restart_service()

    def _restart_service(self):
        check_call(['initctl', 'restart', 'address-book-service'])
