# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures
import os
import shutil

DEFAULT_STORE_ROOT = os.path.expanduser('~/.tmp_backup')


class BackupRestoreFixture(fixtures.Fixture):
    """Generic fixture class to backup and restore a specific directory."""

    def __init__(self, backup_dir, storage_root_dir=DEFAULT_STORE_ROOT,
                 start_clean=True):
        """
        :param backup_dir: Directory to be backed up.
        :param storage_root_dir: Root directoty to use as backup.
        :param start_clean: Whether to clean the backup directory.
        """
        if not os.path.exists(storage_root_dir):
            os.makedirs(storage_root_dir)
        self.backup_dir = backup_dir
        self.storage_dir = fixtures.TempDir(storage_root_dir)
        self.start_clean = start_clean

    def setUp(self):
        """Backup the required directory and register restore actions."""
        super().setUp()
        self.useFixture(self.storage_dir)
        self.addCleanup(self._restore_directory)
        shutil.rmtree(self.storage_dir.path)
        if os.path.exists(self.backup_dir):
            if self.start_clean:
                shutil.move(self.backup_dir, self.storage_dir.path)
            else:
                shutil.copytree(self.backup_dir, self.storage_dir.path)

    def _restore_directory(self):
        """Move the backup data back to original location."""
        if os.path.exists(self.backup_dir):
            shutil.rmtree(self.backup_dir)
        if os.path.exists(self.storage_dir.path):
            shutil.move(self.storage_dir.path, self.backup_dir)
