# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import subprocess
from PIL import Image


def get_colour_count(image_path):
    """Return the number of colours in the specified image."""
    img = Image.open(image_path)
    # get a list of colours from total number of pixels in the image
    colours = img.getcolors(img.size[0] * img.size[1])
    return len(colours)


def get_flash_status_from_exif_data(image_path):
    """Return the bool flash status from the exif data of specified file."""
    result = subprocess.check_output(
        ['exiftool', image_path, '-Flash', '-n', '-s', '-s', '-s'])
    result = result.strip().decode()
    if len(result) > 0:
        status = bool(int(result))
    else:
        status = None
    return status
