# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures
import subprocess

from messaging_app import fixture_setup


class MessagingTestEnvironment(fixtures.Fixture):
    """Fixture used to clean up the phone and messaging environment"""

    def setUp(self):
        super(MessagingTestEnvironment, self).setUp()
        self.useFixture(RespawnMessagingApp())
        self.useFixture(UseEmptySmsHistory())
        self.useFixture(fixture_setup.RespawnService())


class UseEmptySmsHistory(fixture_setup.FillCustomSmsHistory):
    """Fixture used to make the history service run with a clean data db"""
    def setUp(self):
        super(UseEmptySmsHistory, self).setUp()

    def _prepare_history_data(self):
        pass


class RespawnMessagingApp(fixtures.Fixture):
    """ As the Messaging app is not stopped properly by using the
    ubuntu-app-stop command, this fixture ensures the app will be stopped at
    the end of the test
    """
    app_name = 'messaging-app'

    def setUp(self):
        super(RespawnMessagingApp, self).setUp()
        self.addCleanup(self._kill_app_to_respawn)
        self._kill_app_to_respawn()

    def _kill_app_to_respawn(self):
        """ This method is used to kill either a process or an app which is not
        stopped properly by using ubuntu-app-stop"""
        subprocess.call(['pkill', '-f', self.app_name])
