# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
import time

from subprocess import check_output

import autopilot
import ubuntuuitoolkit as uitk

from autopilot.exceptions import StateNotFoundError
from urllib.parse import urlparse
from messaging_app import emulators as messaging_emulators

from ubuntu_system_tests.helpers import ofono

logger = logging.getLogger(__name__)


def get_default_sim_for_messages():
    # GSettings rather rudely includes single quotes
    # so we have to strip them
    return check_output(
        ['gsettings', 'get', 'com.ubuntu.phone',
         'default-sim-for-messages'],
        universal_newlines=True).strip().strip("'")


class MainView(messaging_emulators.MainView):

    @autopilot.logging.log_action(logger.info)
    def type_contact_name_and_select_num(self, name, number):
        text_entry = self.get_newmessage_multirecipientinput()
        self.pointing_device.click_object(text_entry)
        text_entry.focus.wait_for(True)
        time.sleep(.3)
        self.keyboard.type(str(name), delay=0.2)
        # Now select the right number from the list
        self.pointing_device.click_object(
            self.get_mobile_number_label(number)
        )

    def get_mobile_number_label(self, number):
        return self.wait_select_single(
            'Label', text='Mobile {}'.format(number)
        )

    def select_sim_if_prompted(self, sim_number):
        prompt = get_default_sim_for_messages()
        if ofono.number_of_sims() > 1 and prompt == 'ask':
            try:
                default_sim_dialog = self.wait_select_single(
                    'Dialog'
                )
            except StateNotFoundError:
                return
            if default_sim_dialog:
                self.pointing_device.click_object(
                    self.get_sim_label(sim_number)
                )

    def get_sim_label(self, sim_number):
        return self.wait_select_single(
            'Label', text='SIM {}'.format(sim_number)
        )

    def get_thread_list(self):
        return self.select_single(objectName='threadList')

    def get_all_labels_for_thread(self, phone_number):
        thread = self.get_thread_from_number(phone_number)
        if thread.phoneNumber == phone_number:
            return thread.select_many('Label')


class MessageDelegateFactory(messaging_emulators.MessageDelegateFactory):
    """Class to get all the messages from the app."""

    def get_mms_content_file_path(self):
        """Return MMSBase for MMS message."""
        file_url = self.select_single(MMSBase).get_media_file_url()
        return urlparse(file_url).path


class MMSBase(uitk.UbuntuUIToolkitCustomProxyObjectBase):
    """Class to examine MMS content."""

    def get_media_file_url(self):
        """Return the file url of the media content."""
        image = self.get_media_container().select_single('QQuickImage')
        return image.get_properties()['source']

    def get_media_container(self):
        """Return container object for media content."""
        return self.select_single('UCUbuntuShape', visible='True')
