# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

from autopilot import (
    introspection,
    logging as autopilot_logging
)
import ubuntuuitoolkit
from unity8.shell.emulators import main_window

from ubuntu_system_tests.helpers.unity8 import greeter as greeter_helpers


logger = logging.getLogger(__name__)


class Unity8(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):

    """Autopilot custom proxy object for the Unity8 shell."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        name = introspection.get_classname_from_path(path)
        if name == b'unity8' and state['applicationName'][1] == 'unity8':
            return True
        return False

    @property
    def main_window(self):
        return self.select_single(main_window.QQuickView)

    @autopilot_logging.log_action(logger.debug)
    def wait_for_greeter_content(self):
        greeter = self.main_window.wait_select_single(objectName='greeter')
        greeter.waiting.wait_for(False)

    @autopilot_logging.log_action(logger.info)
    def unlock(self):
        greeter = self.main_window.get_greeter()
        if greeter.created:
            greeter_helpers.hide_greeter_with_dbus()
            greeter.created.wait_for(False)

    def get_number_of_sessions(self):
        application_window = self.select_single('ApplicationWindow')
        return len(application_window.select_many('SessionContainer'))
