# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2014, 2015 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; version 3.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import autopilot
import ubuntu_system_settings  # NOQA
import ubuntuuitoolkit
from autopilot.matchers import Eventually
from testtools import skipUnless
from testtools.matchers import Contains

from ubuntu_system_tests.helpers import autopilot as autopilot_helpers
from ubuntu_system_tests.helpers.unity8.dash import get_dash
from ubuntu_system_tests.tests import base


class BluetoothTestCase(base.BaseUbuntuSystemTestCase):

    @skipUnless(autopilot_helpers.is_bluetooth_supported(),
                'Bluetooth support required')
    def setUp(self):
        """ Go to Bluetooth page """
        super(BluetoothTestCase, self).setUp()
        unity_proxy = self.launch_unity()
        unity_proxy.unlock()

        apps_scope = get_dash().open_apps_scope()
        apps_scope.click_scope_item('local', 'System Settings')
        self.addCleanup(self.ensure_application_closed,
                        'ubuntu-system-settings')

        self.app = autopilot_helpers.get_proxy_object_for_existing_process(
            'system-settings',
            ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase,
        )
        self.bluetooth_page = self.app.main_view.go_to_bluetooth_page()

    def test_discover_bluetooth_devices(self):
        """Discover Bluetooth devices.

        The test only runs if the 'bluetooth_device_name' option variable
        has been set

        """
        device_name = autopilot.get_test_configuration().get(
            'bluetooth_device_name', None)
        if device_name:
            self.assertThat(
                lambda: self.bluetooth_page.get_disconnected_devices(),
                Eventually(Contains(device_name), timeout=60)
            )
        else:
            self.skipTest('Bluetooth device not declared to be present')
